<?php
/**
* @package care_api
*/

/**
*/
require_once($root_path.'include/care_api_classes/class_core.php');
/**
*  Office methods.
*  Note this class should be instantiated only after a "$db" adodb  connector object  has been established by an adodb instance.
* @author Sylvia Velasco
* @copyright 2002,2003,2004,2005,2005 Elpidio Latorilla
* @package care_api
*/
class Office extends Core {
	/**
	* Table name for office data
	* @var string
	*/
	var $tb='care_office';
	/**
	* Table name for hospital data
	* @var string
	*/
	var $tb_dept='care_hospital';
	/**
	* Table name for phone and contact data
	* @var string
	*/
	var $result;
	/**
	* Holder for preloaded office data
	* @var object adodb record object
	*/
	var $preload_off;
	/**
	* Preloaded flag
	* @var boolean
	*/
	var $is_preloaded=FALSE;
	/**
	* Holder for office count
	* @var int
	*/
	var $off_count;
	/**
	* Holder for current office number
	* @var int
	*/
	var $off_nr;
	/**
	* Field names of care_office table
	* @var array
	*/
	var $tabfields=array('nr',
				'date',
				'location',
				'num_office',
				'description',
				'history',
				'modify_id',
				'modify_time',
				'create_id',
				'create_time',
				'office_nr');
	/**
	* Constructor
	* @param int Office number
	*/
	function Office($nr=0){
		$this->setTable($this->tb);
		$this->setRefArray($this->tabfields);
		$this->off_nr=$nr;
	}
	/**
	* Gets all data from the care_office table
	* @access private
	* @param string WHERE condition of the sql query
	* @param string Sort item
	* @param string  Determines the return type whether adodb object (_OBJECT) or assoc array (_ARRAY, '', empty) 
	* @return mixed boolean or adodb record object or assoc array, determined by param $ret_type
	*/
	function _getalldata($cond='1',$sort='',$ret_type=''){
	    global $db;
		if(empty($sort)) $sort='num_office';
		//if(!empty($cond)) $cond= $cond.' AND ';
		$this->sql="SELECT * FROM $this->tb WHERE $cond ORDER BY $sort";
	    if ($this->res['_gald']=$db->Execute($this->sql)) {
		    if ($this->off_count=$this->res['_gald']->RecordCount()){
				$this->rec_count=$this->off_count;
		        if($ret_type=='_OBJECT') return $this->res['_gald'];
					else return $this->res['_gald']->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}
	/**
	* Gets all office without condition
	* @access public
	* @param string  Sort condition which includes the field name and the sort direction e.g. "ORDER BY name DESC"
	* @return mixed boolean or 2 dimensional array
	*/
	function getAllNoCondition($sort=''){
	    global $db;
		
		if(!empty($sort)) $sort=" ORDER BY $sort";
		$this->sql="SELECT * FROM $this->tb $sort";
	    if ($this->result=$db->Execute($this->sql)) {
		    if ($this->off_count=$this->result->RecordCount()) {
		        return $this->result->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}
	/**
	* Gets all office without condition. The result is assoc array sorted by office formal name
	* @access public
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAll() {
		return $this->_getalldata('1');
	}
	/**
	* Gets all office without condition
	* @access public
	* @param string Sort item e.g. "name"
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAllSort($sort='') {
		return $this->_getalldata('',$sort);
	}
	/**
	* Gets all office with condition
	* @access public
	* @param string Sort item e.g. "name"
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAllCondition($cond='', $sort='') {
		return $this->_getalldata($cond, $sort);
	}
	/**
	* Gets all information of one office. The result is 2 dimensional associative array.
	* @access public
	* @param int Office number
	* @return mixed 1 dimensional associative array or boolean
	*/
	function getOffAllInfo($nr){
	    global $db;
		$this->sql="SELECT * FROM $this->tb WHERE nr='$nr'";
		//echo "SQL--".$this->sql;
	    if ($this->result=$db->Execute($this->sql)) {
		    if ($this->result->RecordCount()) {
		        return $this->result->FetchRow();
			} else {
				return FALSE;
			}
		} else {
		    return FALSE;
		}
	}
	/**
	* Preloads all information  of one office into the objects internal buffer $preload_off and sets the internal flag $is_preloaded.
	* The information is returned individually through the appropriate methods
	* @access public
	* @param int Office number
	* @return  boolean
	*/
	function preloadOff($nr=0){
	    global $db;
		if(!$nr) return FALSE;
		$this->sql="SELECT * FROM $this->tb WHERE nr='$nr'";
	    if ($this->result=$db->Execute($this->sql)) {
		    if ($this->off_count=$this->result->RecordCount()) {
		        $this->preload_off=$this->result->FetchRow();
				$this->is_preloaded=TRUE;
				return TRUE;
			} else {
				return FALSE;
			}
		} else {
		    return FALSE;
		}
	}
	/**
	* Empties the internal buffer $preload_off and resets the internal flag $is_preloaded
	* @access public
	* @return  boolean
	*/
	function unloadOff(){
		if($this->is_preloaded){
			$this->preload_off=NULL;
			$this->is_preloaded=FALSE;
		}
		return TRUE;
	}
	/**
	* Returns the office number. Use preferably after the office was successfully preloaded by the preloadOff() method.
	* @return mixed integer or boolean
	*/
	function Nr(){
		if(!$this->is_preloaded) return FALSE;
		return $this->preload_off['nr'];
	}
	/**
	* Returns the office location. Use preferably after the office was successfully preloaded by the preloadOff() method.
	* @return mixed string or boolean
	*/
	function Location(){
		if(!$this->is_preloaded) return FALSE;
		return $this->preload_off['location'];
	}
	/**
	* Returns the office number. Use preferably after the office was successfully preloaded by the preloadOff() method.
	* @return mixed string or boolean
	*/
	function NumOffice($nr=0){
		if($this->is_preloaded){
			return $this->preload_off['num_office'];
		}elseif($nr){
			$this->off_nr=$nr;
			return $this->_getItem('num_office');
		}else{
			return FALSE;
		}
	}
	/**
	* Returns the office description. Use preferably after the office was successfully preloaded by the preloadOff() method.
	* @return string
	*/
	function Description($nr=0){
		if(!$this->is_preloaded){
			if($nr) $this->off_nr=$nr;
			return $this->_getItem('description');
		}
		return $this->preload_off['description'];
	}
	/**
	* Returns the office hospital nr. Use preferably after the office was successfully preloaded by the preloadOff() method.
	* @return string
	*/
	function HospitalNr($nr=0){
		if(!$this->is_preloaded){
			if($nr) $this->off_nr=$nr;
			return $this->_getItem('hospital_nr');
		}
		return $this->preload_off['hospital_nr'];
	}
	/** 
	* Gets the item information of a office from the care_office table.
	* Use only if the office number was previously set with the constructor or with the setOffNr() method.
	* @access private
	* @param string Item or field name for extracting including name aliasing  with AS
	* @param string actual return name of the item (optional: used if the first param has an aliasing)
	* @return mixed 1 dimensional array or FALSE
	*/
	function _getItem($item='', $retname=''){
	    global $db;
		$row='';
		if(empty($item)) return FALSE;
	    if ($this->result=$db->Execute("SELECT $item FROM $this->tb WHERE nr=$this->off_nr")) {
		    if ($this->result->RecordCount()) {
		        $row=$this->result->FetchRow();
				if(!empty($retname)) return $row[$retname];
					else return $row[$item];
			} else {
				return FALSE;
			}
		}
		else {
		    return FALSE;
		}
	}
	/**
	* Sets the office number used by the object on run time
	* @param character Office number
	*/
	function setOffNr($nr){
		$this->off_nr=$nr;
	}
}
?>
