<?php
/**
* @package care_api*/

/**
*/
require_once($root_path.'include/care_api_classes/class_core.php');
/**
*  Horarios methods.
*  Note this class should be instantiated only after a "$db" adodb  connector object  has been established by an adodb instance.
* @author Santiago Cordovilla
* @copyright 2002,2003,2004,2005,2005 Elpidio Latorilla
* @package care_api
*/
class Horario extends Core {
	/**
	* Nombre de la tabla para los datos de horarios
	* @var string
	*/
	var $tb='care_schedule';
	/**
	* Nombre de la tabla para departamentos
	* @var string
	*/
	var $tb_dept='care_department';
	/**
	* Nombre de la tabla para teléofnos y contactos
	* @var string
	*/
	var $result;
	/**
	* Holder for preloaded hospital data
	* @var object adodb record object
	*/
	var $preload_hor;
	/**
	* Preloaded flag
	* @var boolean
	*/
	var $is_preloaded=FALSE;
	/**
	* Holder for hospital count
	* @var int
	*/
	var $hor_count;
	/**
	* Holder for current hospital number
	* @var int
	*/
	var $hor_nr;
	/**
	* Nombre de campos para tabla horarios
	* @var array
	*/
	var $tabfields=array(   'nr',
  				'date',
  				'time_ini',
  				'time_fin',
  				'history',
  				'modify_id',
  				'modify_time',
  				'create_id',
  				'create_time',
  				'hospital_nr');
	/**
	* Constructor
	* @param int Hospital number
	*/

	function Horario($nr=0){
		$this->setTable($this->tb);
		$this->setRefArray($this->tabfields);
		$this->hor_nr=$nr;
	}

	function getNr(){
		global $db;
		$this->sql="SELECT max(nr) as nr FROM $this->tb";
		if ($this->result=$db->Execute($this->sql)) {
			if ($this->hor_count=$this->result->RecordCount()) {
				return $this->result->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}
	/**
	* Gets all data from the care_hospital table
	* @access private
	* @param string WHERE condition of the sql query
	* @param string Sort item
	* @param string  Determines the return type whether adodb object (_OBJECT) or assoc array (_ARRAY, '', empty) 
	* @return mixed boolean or adodb record object or assoc array, determined by param $ret_type
	*/
	function _getalldata($cond='1',$sort='',$ret_type=''){
	    global $db;
		if(empty($sort)) $sort='time_ini';
		if(!empty($cond)) $cond= $cond;
		$this->sql="SELECT * FROM $this->tb WHERE $cond ORDER BY $sort";
	    if ($this->res['_gald']=$db->Execute($this->sql)) {
		    if ($this->hor_count=$this->res['_gald']->RecordCount()){
				$this->rec_count=$this->hor_count;
		        if($ret_type=='_OBJECT') return $this->res['_gald'];
					else return $this->res['_gald']->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}

	/**
	* Gets all hospital without condition
	* @access public
	* @param string  Sort condition which includes the field name and the sort direction e.g. "ORDER BY name DESC"
	* @return mixed boolean or 2 dimensional array
	*/
	function getAllNoCondition($sort=''){
	    global $db;
		
		if(!empty($sort)) $sort=" ORDER BY $sort";
		$this->sql="SELECT * FROM $this->tb $sort";
	    if ($this->result=$db->Execute($this->sql)) {
		    if ($this->hosp_count=$this->result->RecordCount()) {
		        return $this->result->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}
	/**
	* Gets all hospital without condition. The result is assoc array sorted by hospital formal name
	* @access public
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAll() {
		return $this->_getalldata('1');
	}
	/**
	* Gets all hospital without condition
	* @access public
	* @param string Sort item e.g. "name"
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAllSort1($cond, $sort='') {
		return $this->_getalldata($cond,$sort);
	}
	/**
	* Gets all hospital with condition
	* @access public
	* @param string Sort item e.g. "name"
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAllCondition($cond='', $sort='') {
		return $this->_getalldata($cond, $sort);
	}
	

	/**
	* Returns the hospital number. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return mixed integer or boolean
	*/
	function Nr(){
		if(!$this->is_preloaded) return FALSE;
		return $this->preload_hor['nr'];
	}
	/**
	* Returns the hospital code. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return mixed string or boolean
	*/
	function TimeI(){ //Code
		if(!$this->is_preloaded) return FALSE;
		return $this->preload_hor['time_ini'];
	}
	/**
	* Returns the hospital name. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return mixed string or boolean
	*/
	function TimeF($nr=0){ //name
		if($this->is_preloaded){
			return $this->preload_hosp['time_fin'];
		}elseif($nr){
			$this->hor_nr=$nr;
			return $this->_getItem('time_fin');
		}else{
			return FALSE;
		}
	}
	/**
	* Returns the hospital address. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return string
	*/
	
	/** 
	* Gets the item information of a hospital from the care_hospital table.
	* Use only if the hospital number was previously set with the constructor or with the setHospNr() method.
	* @access private
	* @param string Item or field name for extracting including name aliasing  with AS
	* @param string actual return name of the item (optional: used if the first param has an aliasing)
	* @return mixed 1 dimensional array or FALSE
	*/
	function _getItem($item='', $retname=''){
	    global $db;
		$row='';
		if(empty($item)) return FALSE;
	    if ($this->result=$db->Execute("SELECT $item FROM $this->tb WHERE nr=$this->hor_nr")) {
		    if ($this->result->RecordCount()) {
		        $row=$this->result->FetchRow();
				if(!empty($retname)) return $row[$retname];
					else return $row[$item];
			} else {
				return FALSE;
			}
		}
		else {
		    return FALSE;
		}
	}
	/**
	* Sets the hospital number used by the object on run time
	* @param character Hospital number
	*/
	function setHospNr($nr){
		$this->hor_nr=$nr;
	}
}
?>
