<?php
/**
* @package care_api
*/

/**
*/
require_once($root_path.'include/care_api_classes/class_core.php');
/**
*  Hospital methods.
*  Note this class should be instantiated only after a "$db" adodb  connector object  has been established by an adodb instance.
* @author Sylvia Velasco
* @copyright 2002,2003,2004,2005,2005 Elpidio Latorilla
* @package care_api
*/
class Hospital extends Core {
	/**
	* Table name for hospital data
	* @var string
	*/
	var $tb='care_hospital';
	/**
	* Table name for department data
	* @var string
	*/
	var $tb_dept='care_department';
	/**
	* Table name for phone and contact data
	* @var string
	*/
	var $result;
	/**
	* Holder for preloaded hospital data
	* @var object adodb record object
	*/
	var $preload_hosp;
	/**
	* Preloaded flag
	* @var boolean
	*/
	var $is_preloaded=FALSE;
	/**
	* Holder for hospital count
	* @var int
	*/
	var $hosp_count;
	/**
	* Holder for current hospital number
	* @var int
	*/
	var $hosp_nr;
	/**
	* Field names of care_hospital table
	* @var array
	*/
	var $tabfields=array('nr',
									'name',
									'code',
									'emgcy_nr',
									'phone_nr',
									'fax_nr',
									'address',
									'email',
									'status',
									'history',
									'modify_id',
									'modify_time',
									'create_id',
									'create_time',
									'url_logo',
									'is_inactive');
	/**
	* Constructor
	* @param int Hospital number
	*/
	function Hospital($nr=0){
		$this->setTable($this->tb);
		$this->setRefArray($this->tabfields);
		$this->hosp_nr=$nr;
	}
	/**
	*
	*
	**/
	function getNr(){
		global $db;
		$this->sql="SELECT max(nr) as nr FROM $this->tb";
		if ($this->result=$db->Execute($this->sql)) {
			if ($this->hosp_count=$this->result->RecordCount()) {
				return $this->result->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}
	/**
	* Gets all data from the care_hospital table
	* @access private
	* @param string WHERE condition of the sql query
	* @param string Sort item
	* @param string  Determines the return type whether adodb object (_OBJECT) or assoc array (_ARRAY, '', empty) 
	* @return mixed boolean or adodb record object or assoc array, determined by param $ret_type
	*/
	function _getalldata($cond='1',$sort='',$ret_type=''){
	    global $db;
		if(empty($sort)) $sort='name';
		if(!empty($cond)) $cond= $cond.' AND ';
		$this->sql="SELECT * FROM $this->tb WHERE $cond status NOT IN ($this->dead_stat) ORDER BY $sort";
	    if ($this->res['_gald']=$db->Execute($this->sql)) {
		    if ($this->hosp_count=$this->res['_gald']->RecordCount()){
				$this->rec_count=$this->hosp_count;
		        if($ret_type=='_OBJECT') return $this->res['_gald'];
					else return $this->res['_gald']->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}
	/**
	* Gets all hospital without condition
	* @access public
	* @param string  Sort condition which includes the field name and the sort direction e.g. "ORDER BY name DESC"
	* @return mixed boolean or 2 dimensional array
	*/
	function getAllNoCondition($sort=''){
	    global $db;
		
		if(!empty($sort)) $sort=" ORDER BY $sort";
		$this->sql="SELECT * FROM $this->tb $sort";
	    if ($this->result=$db->Execute($this->sql)) {
		    if ($this->hosp_count=$this->result->RecordCount()) {
		        return $this->result->GetArray();
			}else{
				return FALSE;
			}
		}else{
		    return FALSE;
		}
	}
	/**
	* Gets all hospital without condition. The result is assoc array sorted by hospital formal name
	* @access public
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAll() {
		return $this->_getalldata('1');
	}
	/**
	* Gets all hospital without condition
	* @access public
	* @param string Sort item e.g. "name"
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAllSort($sort='') {
		return $this->_getalldata('',$sort);
	}
	/**
	* Gets all hospital with condition
	* @access public
	* @param string Sort item e.g. "name"
	* @return mixed boolean or adodb record object or assoc array
	*/
	function getAllCondition($cond='', $sort='') {
		return $this->_getalldata($cond, $sort);
	}
	/**
	* Gets all information of one hospital. The result is 2 dimensional associative array.
	* @access public
	* @param int Hospital number
	* @return mixed 1 dimensional associative array or boolean
	*/
	function getHospAllInfo($nr){
	    global $db;
		$this->sql="SELECT * FROM $this->tb WHERE nr='$nr'";
		//echo "SQL--".$this->sql;
	    if ($this->result=$db->Execute($this->sql)) {
		    if ($this->result->RecordCount()) {
		        return $this->result->FetchRow();
			} else {
				return FALSE;
			}
		} else {
		    return FALSE;
		}
	}
	/**
	* Preloads all information  of one hospital into the objects internal buffer $preload_hosp and sets the internal flag $is_preloaded.
	* The information is returned individually through the appropriate methods
	* @access public
	* @param int Hospital number
	* @return  boolean
	*/
	function preloadHosp($nr=0){
	    global $db;
		if(!$nr) return FALSE;
		$this->sql="SELECT * FROM $this->tb WHERE nr='$nr'";
	    if ($this->result=$db->Execute($this->sql)) {
		    if ($this->hosp_count=$this->result->RecordCount()) {
		        $this->preload_hosp=$this->result->FetchRow();
				$this->is_preloaded=TRUE;
				return TRUE;
			} else {
				return FALSE;
			}
		} else {
		    return FALSE;
		}
	}
	/**
	* Empties the internal buffer $preload_hosp and resets the internal flag $is_preloaded
	* @access public
	* @return  boolean
	*/
	function unloadHosp(){
		if($this->is_preloaded){
			$this->preload_hosp=NULL;
			$this->is_preloaded=FALSE;
		}
		return TRUE;
	}
	/**
	* Returns the hospital number. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return mixed integer or boolean
	*/
	function Nr(){
		if(!$this->is_preloaded) return FALSE;
		return $this->preload_hosp['nr'];
	}
	/**
	* Returns the hospital code. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return mixed string or boolean
	*/
	function Code(){
		if(!$this->is_preloaded) return FALSE;
		return $this->preload_hosp['code'];
	}
	/**
	* Returns the hospital name. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return mixed string or boolean
	*/
	function Name($nr=0){
		if($this->is_preloaded){
			return $this->preload_hosp['name'];
		}elseif($nr){
			$this->hosp_nr=$nr;
			return $this->_getItem('name');
		}else{
			return FALSE;
		}
	}
	/**
	* Returns the hospital address. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return string
	*/
	function Address($nr=0){
		if(!$this->is_preloaded){
			if($nr) $this->hosp_nr=$nr;
			return $this->_getItem('address');
		}
		return $this->preload_hosp['address'];
	}
	/**
	* Returns the hospital emgcy nr. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return string
	*/
	function EmgcyNr($nr=0){
		if(!$this->is_preloaded){
			if($nr) $this->hosp_nr=$nr;
			return $this->_getItem('emgcy_nr');
		}
		return $this->preload_hosp['emgcy_nr'];
	}
	/**
	* Returns the hospital phone nr. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return string
	*/
	function PhoneNr($nr=0){
		if(!$this->is_preloaded){
			if($nr) $this->hosp_nr=$nr;
			return $this->_getItem('phone_nr');
		}
		return $this->preload_hosp['phone_nr'];
	}
	/**
	* Returns the hospital fax nr. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return string
	*/
	function FaxNr($nr=0){
		if(!$this->is_preloaded){
			if($nr) $this->hosp_nr=$nr;
			return $this->_getItem('fax_nr');
		}
		return $this->preload_hosp['fax_nr'];
	}
	/**
	* Returns the hospital email. Use preferably after the hospital was successfully preloaded by the preloadHosp() method.
	* @return string
	*/
	function Email($nr=0){
		if(!$this->is_preloaded){
			if($nr) $this->hosp_nr=$nr;
			return $this->_getItem('email');
		}
		return $this->preload_hosp['email'];
	}
	/** 
	* Gets the item information of a hospital from the care_hospital table.
	* Use only if the hospital number was previously set with the constructor or with the setHospNr() method.
	* @access private
	* @param string Item or field name for extracting including name aliasing  with AS
	* @param string actual return name of the item (optional: used if the first param has an aliasing)
	* @return mixed 1 dimensional array or FALSE
	*/
	function _getItem($item='', $retname=''){
	    global $db;
		$row='';
		if(empty($item)) return FALSE;
	    if ($this->result=$db->Execute("SELECT $item FROM $this->tb WHERE nr=$this->hosp_nr")) {
		    if ($this->result->RecordCount()) {
		        $row=$this->result->FetchRow();
				if(!empty($retname)) return $row[$retname];
					else return $row[$item];
			} else {
				return FALSE;
			}
		}
		else {
		    return FALSE;
		}
	}
	/**
	* Sets the hospital number used by the object on run time
	* @param character Hospital number
	*/
	function setHospNr($nr){
		$this->hosp_nr=$nr;
	}
}
?>
